@@ -21,10 +21,11 @@
 #' @param  timeName the name of the variable that contains time information.
 #' @param  useTau  if TRUE the log ratio of indicator values is divided for
 #'         the elapsed time (years).
+#' @param useCon if TRUE replaces 0 with a minimum constant value
 #' @return a list with the value of beta-conv, by OLS (least-squares), the
 #'         transformed data and standard statistical tests.
 #'
-#' @references{\url{https://unimi2013-my.sharepoint.com/:u:/g/personal/federico_stefanini_unimi_it/EW0cVSIgbtZAvLPNbqcxdX8Bfn5VGSRHfAH88hQwc_RIEQ?e=MgtSZu}}
+#' @references{ \url{https://www.eurofound.europa.eu/system/files/2022-04/introduction-to-the-convergeu-package-0.6.4-tutorial-v2-apr2022.pdf}}
 #'
 #' @importFrom  rlang  .data
 #' @examples
@@ -84,7 +85,9 @@
 #' @export
 #'
 beta_conv <- function(tavDes,time_0, time_t, all_within=FALSE,
-                      timeName = "time",  useTau = TRUE){
+                      timeName = "time",  useTau = TRUE, useCon = FALSE){
+
+
   obj_out <- convergEU_glb()$tmpl_out
   # check if timeName is present
   if(not_in(timeName,names(tavDes))) {
@@ -104,18 +107,38 @@ beta_conv <- function(tavDes,time_0, time_t, all_within=FALSE,
     obj_out$err <- "Error: wrong selected time window."
     return(obj_out);
   }
+  # implementing constant where min is 0
+  ecode <- names(tavDes)[-c(1)]
+  tempo_val1 <- unlist(tavDes[,ecode])
+  tempo_val <- tempo_val1[tempo_val1 > 0]
+  if(useCon){
+    minim_not_null <- min(tempo_val)/100
+    if(all(tavDes[,ecode] >= 0)){
+      for(auxvv in ecode){
+        estrattore_nulli <- tavDes[[auxvv]] == 0
+        tavDes[[auxvv]][estrattore_nulli] <- minim_not_null
+      }
+    }
+  }else{
+    if(length(tempo_val1) > length(tempo_val)){
+      obj_out$err <- "Error: One or more values zero or negative"
+    }
+  }
+
+
   # Make standard checks on the dataframe
   tt_out <- check_data(tavDes, timeName = timeName)
   if(!is.null(tt_out$err)){
     return(tt_out);
-    }
+  }
   # At least three columns and 2 rows needed due to differencing
   if(nrow(tavDes) < 2 && ncol(tavDes) < 4){
     obj_out$err <- "Error: at least 2 rows and 4 columns needed in the dataframe."
     return(obj_out)
-    }
+  }
   # extract and sort
   tavDes <- dplyr::arrange_at(tavDes,timeName)
+  #timeRaw <- unlist(tavDes[,timeName])
   timeRaw <- tavDes[[timeName]]
   pos_t0 <- which(timeRaw == time_0)
   pos_tt <- which(timeRaw == time_t)
@@ -127,53 +150,44 @@ beta_conv <- function(tavDes,time_0, time_t, all_within=FALSE,
   }
   #
   if(all_within) {# all times within the interval
-      resTB <- tavDes[pos_all,]
-      # sorted by time
-      resTB <- dplyr::arrange_at(resTB,timeName)
-   }else{
-      #just the two considered rows
-      resTB <- tavDes[c(pos_t0,pos_tt),]
-      };
+    resTB <- tavDes[pos_all,]
+    # sorted by time
+    resTB <- dplyr::arrange_at(resTB,timeName)
+  }else{
+    #just the two considered rows
+    resTB <- tavDes[c(pos_t0,pos_tt),]
+  };
   # now it it sure the reference is in the first row
   # Non negative values? Needed because log(indicator) taken
-  check_negative <- dplyr::select(resTB,
-                tidyselect::all_of(
-                   setdiff(
-                     names(resTB),
-                     timeName)))
-  if( sum(check_negative  <= 0) > 0){
-      obj_out$err  <- "Error: negative values in the indicator."
+  if( sum(resTB[,-which(names(resTB) == timeName)]  <= 0) > 0){    ###########dplyr::select(resTB, -timeName)  <= 0) > 0){
+    obj_out$err  <- "Error: negative values in the indicator."
     return(obj_out)
   }
   # log-transform, already checked positivity
-  reslogTB <- log(dplyr::select(resTB,
-                                tidyselect::all_of(
-                                  setdiff(
-                                    names(resTB),timeName))))
+  reslogTB <- log(resTB[,-which(names(resTB) == timeName)])    ##########dplyr::select(resTB, -timeName))
+  ## wTB <- cbind(dplyr::select(resTB, timeName),reslogTB)
   ## Should we divide the ordinates by number of elapsed years? YES, possibly
   workTB <- dplyr::tibble(
-        deltaIndic = as.numeric(reslogTB[2,] - reslogTB[1,]),
-        indic = as.numeric(reslogTB[1,]),
-        countries = names(reslogTB))
+    deltaIndic = as.numeric(reslogTB[2,] - reslogTB[1,]),
+    indic = as.numeric(reslogTB[1,]),
+    countries = names(reslogTB))
   if(useTau){
     # divide by elapsed time
-     tmp_DIDT<- workTB$deltaIndic/delta_time
-    workTB <- dplyr::mutate(workTB, deltaIndic = tmp_DIDT);
-    }
+    workTB <- dplyr::mutate(workTB, deltaIndic = .data$deltaIndic / delta_time);
+  }
   #
   if(nrow(reslogTB) > 2){# several years besides time_t and time_0
     for(auxR in 3:nrow(reslogTB)){
-       tmpTB <- dplyr::tibble(
-         deltaIndic = as.numeric(reslogTB[auxR,] - reslogTB[1,]),
-         indic = as.numeric(reslogTB[1,]),# maybe reslogTB[auxR-1, ]
-         countries = names(reslogTB))
-       # tau?
-       if(useTau){
-         # divide by elapsed time
-         tmpTB_DIDT <- tmpTB$deltaIndic/delta_time
-         tmpTB <- dplyr::mutate(tmpTB, deltaIndic = tmpTB_DIDT);
-         }
-        workTB <- rbind(workTB,tmpTB)# end add_row
+      tmpTB <- dplyr::tibble(
+        deltaIndic = as.numeric(reslogTB[auxR,] - reslogTB[1,]),
+        indic = as.numeric(reslogTB[1,]),# maybe reslogTB[auxR-1, ]
+        countries = names(reslogTB))
+      # tau?
+      if(useTau){
+        # divide by elapsed time
+        tmpTB <- dplyr::mutate(tmpTB, deltaIndic = .data$deltaIndic / delta_time);
+      }
+      workTB <- rbind(workTB,tmpTB)# end add_row
     };
   }# end several years
   #
@@ -189,5 +203,3 @@ beta_conv <- function(tavDes,time_0, time_t, all_within=FALSE,
   obj_out$res$beta1 <- as.numeric(obj_out$res$summary[2,2])
   return(obj_out)
 }
-
-utils::globalVariables(c(".data"))
