@@ -1,15 +1,16 @@
 ## ----setup, include = FALSE---------------------------------------------------
-require(ggplot2)
-require(dplyr)
-require(tidyverse)
-require(convergEU)
-require(eurostat)
-require(purrr)
-require(tibble)
-require(tidyr)
-require(formattable) 
-require(kableExtra)
-require(caTools)
+library(ggplot2)
+library(dplyr)
+library(tidyverse)
+library(eurostat)
+library(purrr)
+library(tibble)
+library(tidyr)
+library(formattable) 
+library(kableExtra)
+library(caTools)
+
+library(convergEU)
 
 knitr::opts_chunk$set(
   collapse = TRUE,
@@ -28,9 +29,9 @@ knitr::opts_chunk$set(
 
 ## ----eval=FALSE---------------------------------------------------------------
 #  help(emp_20_64_MS)
+#  
 
 ## -----------------------------------------------------------------------------
-require(convergEU)
 data(dbEurofound)
 head(dbEurofound)
 
@@ -106,14 +107,14 @@ myTB <- extract_indicator_EUF(
 sapply(myTB$res,function(vx)sum(is.na(vx)))
 
 ## -----------------------------------------------------------------------------
-myTB2 <- dplyr::bind_rows(myTB,myTB,myTB)
-myTB2[["time"]][1:3] <- c(1975,1980,1985)
-myTB2[["time"]][4:6] <- c(1990,1995,2000)
-
+set.seed(1999)
+myTB2 <- dplyr::bind_rows(myTB$res,myTB$res,myTB$res)
+myTB2 <- dplyr::mutate(myTB2, time= seq(1975,2015,5))
 for(aux in 3:14){
-  myTB2[[aux]][c(1:3,4:6)] <-   myTB2[[aux]][c(1:3,4:6)] + runif(6,-2.5,2.5)
+  myTB2[[aux]] <-   myTB2[[aux]] + c(runif(6,-2.5,2.5),0,0,0)
 }
 
+## -----------------------------------------------------------------------------
 myTB2[["BE"]][1:2] <-  NA
 myTB2[["DE"]][8:9] <-  NA
 myTB2[["IT"]][c(3,4, 6,7,8)] <-  NA
@@ -136,9 +137,9 @@ impute_dataset(myTB2, countries=toBeProcessed,
 
 
 ## -----------------------------------------------------------------------------
-require(ggplot2)
-require(dplyr)
-require(tibble)
+#library(ggplot2)
+#library(dplyr)
+#library(tibble)
 
 testTB <- tribble(
   ~time, ~countryA ,  ~countryB,  ~countryC,
@@ -495,7 +496,8 @@ resSM <- smoo_dataset(select(workTB,-time), leadW = 0.149, timeTB= select(workTB
 resSM
 
 ## -----------------------------------------------------------------------------
-compaTB <- select(bind_cols(workTB, select(resSM,-time)), time,IT,IT1,DE,DE1)
+tmpSM <- dplyr::rename(dplyr::select(resSM,-time),IT1=IT,DE1=DE)
+compaTB <- dplyr::select(bind_cols(workTB, tmpSM), time,IT,IT1,DE,DE1)
 compaTB
 
 ## ----out.width="70%"----------------------------------------------------------
@@ -512,8 +514,11 @@ qplot(time,DE,data=compaTB) +
 
 
 ## ----out.width="70%"----------------------------------------------------------
-resSM <- smoo_dataset(select(workTB,-time), leadW = 1, timeTB= select(workTB,time))
-compaTB <- select(bind_cols(workTB, select(resSM,-time)), time,IT,IT1,DE,DE1)
+resSM <- smoo_dataset(dplyr::select(workTB,-time), leadW = 1,
+                      timeTB= dplyr::select(workTB,time))
+resSM <- dplyr::rename(resSM,IT1=IT, DE1=DE)
+compaTB <- dplyr::select(dplyr::bind_cols(workTB, 
+                     dplyr::select(resSM,-time)), time,IT,IT1,DE,DE1)
 qplot(time,IT,data=compaTB) + 
   geom_line(colour="navyblue") +
   geom_line(aes(x=time,y=IT1),colour="red") +
@@ -526,17 +531,17 @@ cuTB <- dplyr::mutate(cuTB,time =emp_20_64_MS$time)
 
 ## -----------------------------------------------------------------------------
 
-cuTB <-  dplyr:: mutate(cuTB, IT_k_3= runmean(emp_20_64_MS$IT, k=3, 
+cuTB <-  dplyr:: mutate(cuTB, IT_k_3= caTools::runmean(emp_20_64_MS$IT, k=3, 
         alg=c("C", "R", "fast", "exact")[4],
         endrule=c("mean", "NA", "trim", "keep", "constant", "func")[4],
         align = c("center", "left", "right")[1]))
 
-cuTB <-  dplyr:: mutate(cuTB, IT_k_5= runmean(emp_20_64_MS$IT, k=5, 
+cuTB <-  dplyr:: mutate(cuTB, IT_k_5= caTools::runmean(emp_20_64_MS$IT, k=5, 
         alg=c("C", "R", "fast", "exact")[4],
         endrule=c("mean", "NA", "trim", "keep", "constant", "func")[4],
         align = c("center", "left", "right")[1]))
 
-cuTB <-  dplyr:: mutate(cuTB, IT_k_7= runmean(emp_20_64_MS$IT, k=7, 
+cuTB <-  dplyr:: mutate(cuTB, IT_k_7= caTools::runmean(emp_20_64_MS$IT, k=7, 
         alg=c("C", "R", "fast", "exact")[4],
         endrule=c("mean", "NA", "trim", "keep", "constant", "func")[4],
         align = c("center", "left", "right")[1]))
@@ -602,8 +607,8 @@ resTB <- scoreb_yrs(emp_20_64_MS,timeName = "time")
 resTB
 
 ## -----------------------------------------------------------------------------
-# require(ggplot2)
-# data(emp_20_64_MS)
+# library(ggplot2)
+data(emp_20_64_MS)
 selectedCountry <- "IT"
 timeName <-  "time"
 myx_angle <-  45
