@@ -9,7 +9,7 @@ test_that("Beta convergence,  scrambled time and  different name, two times.", {
   #   c(88,   1201, 868, 578,
   #     89,   1150, 978, 682,
   #     90,   998,  1250, 332,
-  #     91,  1600,  1350, 802),ncol=4,byrow=TRUE
+  #     91,  1600,  1350, 802),ncol=4,byrow=T
   # )
   # scrambled data
   myTB2  <- tibble::tribble(
@@ -41,7 +41,8 @@ test_that("Beta convergence,  scrambled time and  different name, two times.", {
   beta1 <- as.numeric(lm( risposte ~ xval)$coeff[2])
   expect_equal(as.numeric(res_sigori$res$model$coefficients[2]),
                beta1)
-  
+  #expect_equal(res_sigori$res$model$coefficients[2],
+  #             beta1)
 
 })
 
@@ -150,7 +151,8 @@ test_that("Beta convergence,  several  times.", {
                               2018,
                               all_within=FALSE,
                               timeName="time",
-                              useTau=TRUE)
+                              useTau=TRUE,
+                              useCon = TRUE)
         #
         expect_true(is.null(res_beta$err))
     })
@@ -407,7 +409,7 @@ test_that("Delta convergence,  highBest  extended.", {
                             indiType = "highBest",
                             time_0=88,
                             time_t=90,
-                            extended=TRUE)
+                            extended=T)
 
   expect_true(!res_deltaLB$res$strict_conv_ini_last)
   expect_true(!res_deltaLB$res$converg_ini_last)
@@ -431,13 +433,13 @@ test_that("Delta convergence,  check  not extended.", {
                             indiType = "highBest",
                             time_0=89,
                             time_t=90,
-                            extended=FALSE)
+                            extended=F)
   res_delta2  <- delta_conv(myTB,
                            timeName="time",
                            indiType = "lowBest",
                            time_0=89,
                            time_t=90,
-                           extended=FALSE)
+                           extended=F)
   expect_equal(res_delta$res$delta , c(640,1170))
   expect_equal(res_delta2$res$delta,c(sum(c(1150, 978)- 682),
                                       sum(c(998,  1250)- 332)))
@@ -462,7 +464,7 @@ test_that("Delta convergence,  highBest   extended.", {
                            indiType = "highBest",
                            time_0=88,
                            time_t=90,
-                           extended=TRUE)
+                           extended=T)
 
 
   expect_true(res_delta$res$converg_ini_last)
@@ -486,7 +488,7 @@ test_that("Delta convergence,  lowBest   extended.", {
                            indiType = "lowBest",
                            time_0=88,
                            time_t=90,
-                           extended=TRUE)
+                           extended=T)
 
 
   expect_true(res_delta$res$converg_ini_last)
@@ -504,7 +506,7 @@ test_that("Delta convergence,  lowBest   extended.", {
                            indiType = "lowBest",
                            time_0=88,
                            time_t=90,
-                           extended=TRUE)
+                           extended=T)
   expect_true(res_delta2$res$converg_ini_last)
   expect_false(res_delta2$res$strict_conv_ini_last)
 })
@@ -523,7 +525,7 @@ test_that("Delta convergence,  constant   extended.", {
                             indiType = "lowBest",
                             time_0=88,
                             time_t=90,
-                            extended=TRUE)
+                            extended=T)
   expect_false(res_delta3$res$converg_ini_last)
   expect_false(res_delta3$res$strict_conv_ini_last)
 
@@ -532,7 +534,7 @@ test_that("Delta convergence,  constant   extended.", {
                             indiType = "highBest",
                             time_0=88,
                             time_t=90,
-                            extended=TRUE)
+                            extended=T)
   expect_false(res_delta3$res$converg_ini_last)
   expect_false(res_delta3$res$strict_conv_ini_last)
 })
@@ -681,7 +683,7 @@ test_that("Gamma convergence,  scrambled time and  different name.", {
      c(88,   rank(c(1201, 868, 578)),
        89,   rank(c(1150, 978, 682)),
        90,   rank(c(998,  1250, 332)),
-       91,  rank(c(1600,  1350, 802))),ncol=4,byrow=TRUE
+       91,  rank(c(1600,  1350, 802))),ncol=4,byrow=T
    )
    sumRan <- apply(soDat[,-1],2,sum)
    numerator <- pop_var(sumRan)$popvar
@@ -710,7 +712,7 @@ test_that("Gamma convergence,  regular time  different reference time and last."
       89,   rank(c(1150, 978, 682)),
       90,   rank(c(998,  1250, 332))
       #91,  rank(c(1600,  1350, 802))
-      ),ncol=4,byrow=TRUE
+      ),ncol=4,byrow=T
   )
   sumRan <- apply(soDat[,-1],2,sum)
   numerator <- pop_var(sumRan)$popvar
